==> blanco.plugin.svnconf_0.0.7-src.zip: src/blanco/svnconf/message/BlancoSvnConfMessageResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.svnconf.message;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoSvnConfMessage/bZ[W`[BlancoSvnConf]Iɗp郊\[XohNXB]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 */
class BlancoSvnConfMessageResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoSvnConfMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoSvnConfMessage]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoSvnConfMessageResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoSvnConfMessage");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoSvnConfMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoSvnConfMessage]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoSvnConfMessageResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoSvnConfMessage", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoSvnConfMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoSvnConfMessage]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoSvnConfMessageResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoSvnConfMessage", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC01]
     *
     * [|Wg`ID[{0}]̃zXgw肳Ă܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC01]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc01(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]̃zXgw肳Ă܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC01");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC02]
     *
     * [|Wg`ID[{0}]̊fBNgw肳Ă܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC02]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc02(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]̊fBNgw肳Ă܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC02");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC03]
     *
     * [|Wg`ID[{0}]ɂāApID[{1}]2ȏ゠܂Bp҂2ȏw肷邱Ƃ͂ł܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC03]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc03(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]ɂāApID[{1}]2ȏ゠܂Bp҂2ȏw肷邱Ƃ͂ł܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC03");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC04]
     *
     * [|Wg`ID[{0}]ɂāApID[{1}]̌w肳Ă܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC04]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc04(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]ɂāApID[{1}]̌w肳Ă܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC04");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC05]
     *
     * [|Wg`ID[{0}]ɂāApID[{1}]̖̂słBpIDɂ *͊܂߂ȂŉB] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC05]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc05(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]ɂāApID[{1}]̖̂słBpIDɂ *͊܂߂ȂŉB";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC05");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC06]
     *
     * [|Wg`ID[{0}]ɂāAfBNg[{1}]̖̂słBfBNg /  \ ŏIȂ悤ɂĂB] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC06]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc06(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]ɂāAfBNg[{1}]̖̂słBfBNg /  \\ ŏIȂ悤ɂĂB";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC06");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC07]
     *
     * [|Wg`܂āÃzXgo^Ă܂B̓Iɂ́A|Wg`ID[{0}][{1}] |Wg`ID[{2}][{3}]ɂāAzXgقȂĂ܂B̂悤Ȓ`xɏ邱Ƃ͂ł܂Bx̏ɂẮA`ԂŃzXgP̏ԂɂȂ悤ɂďs悤ɂĂB] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @param arg2 u{2}ulBjava.lang.String^^ĂB
     * @param arg3 u{3}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC07]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc07(final String arg0, final String arg1, final String arg2, final String arg3) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`܂āÃzXgo^Ă܂B̓Iɂ́A|Wg`ID[{0}][{1}] |Wg`ID[{2}][{3}]ɂāAzXgقȂĂ܂B̂悤Ȓ`xɏ邱Ƃ͂ł܂Bx̏ɂẮA`ԂŃzXgP̏ԂɂȂ悤ɂďs悤ɂĂB";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC07");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1, arg2, arg3}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC08]
     *
     * [|Wg`ID[{0}]ɂāAǗIDw肳Ă܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC08]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc08(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]ɂāAǗIDw肳Ă܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC08");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC09]
     *
     * [|Wg`ID[{0}]2ȏ㑶݂Ă܂B|WgID͏dȂłB[{1}][{2}]] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @param arg2 u{2}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC09]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc09(final String arg0, final String arg1, final String arg2) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]2ȏ㑶݂Ă܂B|WgID͏dȂłB[{1}][{2}]";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC09");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1, arg2}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNCA1]
     *
     * [^fBNg[{0}]݂܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBSVNCA1]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnca1(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "^fBNg[{0}]݂܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNCA1");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }
}

==> blanco.plugin.svnconf_0.1.1-src.zip: src/blanco/svnconf/message/BlancoSvnConfMessageResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.svnconf.message;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoSvnConfMessage/bZ[W`[BlancoSvnConf]Iɗp郊\[XohNXB]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 */
class BlancoSvnConfMessageResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoSvnConfMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoSvnConfMessage]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoSvnConfMessageResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/svnconf/message/BlancoSvnConfMessage");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoSvnConfMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoSvnConfMessage]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoSvnConfMessageResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/svnconf/message/BlancoSvnConfMessage", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoSvnConfMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoSvnConfMessage]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoSvnConfMessageResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/svnconf/message/BlancoSvnConfMessage", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC01]
     *
     * [|Wg`ID[{0}]̃zXgw肳Ă܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC01]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc01(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]̃zXgw肳Ă܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC01");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC02]
     *
     * [|Wg`ID[{0}]̊fBNgw肳Ă܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC02]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc02(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]̊fBNgw肳Ă܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC02");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC03]
     *
     * [|Wg`ID[{0}]ɂāApID[{1}]2ȏ゠܂Bp҂2ȏw肷邱Ƃ͂ł܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC03]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc03(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]ɂāApID[{1}]2ȏ゠܂Bp҂2ȏw肷邱Ƃ͂ł܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC03");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC04]
     *
     * [|Wg`ID[{0}]ɂāApID[{1}]̌w肳Ă܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC04]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc04(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]ɂāApID[{1}]̌w肳Ă܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC04");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC05]
     *
     * [|Wg`ID[{0}]ɂāApID[{1}]̖̂słBpIDɂ *͊܂߂ȂŉB] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC05]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc05(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]ɂāApID[{1}]̖̂słBpIDɂ *͊܂߂ȂŉB";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC05");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC06]
     *
     * [|Wg`ID[{0}]ɂāAfBNg[{1}]̖̂słBfBNg /  \ ŏIȂ悤ɂĂB] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC06]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc06(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]ɂāAfBNg[{1}]̖̂słBfBNg /  \\ ŏIȂ悤ɂĂB";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC06");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC07]
     *
     * [|Wg`܂āÃzXgo^Ă܂B̓Iɂ́A|Wg`ID[{0}][{1}] |Wg`ID[{2}][{3}]ɂāAzXgقȂĂ܂B̂悤Ȓ`xɏ邱Ƃ͂ł܂Bx̏ɂẮA`ԂŃzXgP̏ԂɂȂ悤ɂďs悤ɂĂB] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @param arg2 u{2}ulBjava.lang.String^^ĂB
     * @param arg3 u{3}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC07]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc07(final String arg0, final String arg1, final String arg2, final String arg3) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`܂āÃzXgo^Ă܂B̓Iɂ́A|Wg`ID[{0}][{1}] |Wg`ID[{2}][{3}]ɂāAzXgقȂĂ܂B̂悤Ȓ`xɏ邱Ƃ͂ł܂Bx̏ɂẮA`ԂŃzXgP̏ԂɂȂ悤ɂďs悤ɂĂB";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC07");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1, arg2, arg3}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC08]
     *
     * [|Wg`ID[{0}]ɂāAǗIDw肳Ă܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC08]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc08(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]ɂāAǗIDw肳Ă܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC08");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNC09]
     *
     * [|Wg`ID[{0}]2ȏ㑶݂Ă܂B|WgID͏dȂłB[{1}][{2}]] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @param arg2 u{2}ulBjava.lang.String^^ĂB
     * @return key[MBSVNC09]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnc09(final String arg0, final String arg1, final String arg2) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "|Wg`ID[{0}]2ȏ㑶݂Ă܂B|WgID͏dȂłB[{1}][{2}]";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNC09");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1, arg2}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoSvnConfMessage], key[MBSVNCA1]
     *
     * [^fBNg[{0}]݂܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBSVNCA1]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbsvnca1(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "^fBNg[{0}]݂܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBSVNCA1");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }
}
